@@ -5,4 +5,4 @@ class Provider(CurrencyProvider):
     price_formats = ["#,##", "%#,##", "%##,##", "%.###,##", "%#.###,##"]
 
     def pricetag(self) -> str:
-        return self.numerify(self.random_element(self.price_formats)) + "\N{no-break space}\N{euro sign}"
+        return self.numerify(self.random_element(self.price_formats)) + "\N{NO-BREAK SPACE}\N{EURO SIGN}"
